==> chainwallet-1.0.2.tar.gz: lib/src/core/coretypes/STObjectFormatter.dart <==
import 'dart:core';

import 'package:chainwallet/src/core/coretypes/STObject.dart';

import 'package:chainwallet/src/core/serialized/enums/TransactionType.dart';

import 'package:chainwallet/src/core/types/tx/Transaction.dart';
import 'package:chainwallet/src/core/types/txns/Payment.dart';
import 'package:chainwallet/src/core/types/txns/TrustSet.dart';

/***
 *
 *
 *
 */
class STObjectFormatter {


  //TODO
  static STObject doFormatted(STObject source) {
    // This would need to go before the test that just checks
    // for ledgerEntryType
//    if (AffectedNode.isAffectedNode(source)) {
//      return new AffectedNode(source);
//    }
//
//    if (TransactionMeta.isTransactionMeta(source)) {
//      TransactionMeta meta = new TransactionMeta();
//      meta.fields = source.fields;
//      return meta;
//    }
//
//    LedgerEntryType ledgerEntryType = STObject.ledgerEntryType(source);
//    if (ledgerEntryType != null) {
//      return ledgerFormatted(source, ledgerEntryType);
//    }
//
    TransactionType transactionType = STObject.transactionType(source);
    if (transactionType != null) {
      return transactionFormatted(source, transactionType);
    }

    return source;
  }




  static STObject transactionFormatted(STObject source, TransactionType transactionType) {
    STObject constructed = null;

    if(transactionType.runtimeType == TransactionType.Invalid){

    }else if(transactionType.runtimeType == TransactionType.Payment){
          constructed = new Payment();
    }else if(transactionType.runtimeType == TransactionType.TrustSet){
      constructed = new TrustSet();
    }

    if (constructed == null) {
      constructed = new Transaction(transactionType);
    }

    constructed.fields = source.fields;
    return constructed;

  }

}

==> chainwallet-1.0.4.tar.gz: lib/src/core/coretypes/STObjectFormatter.dart <==
import 'dart:core';

import 'package:chainwallet/src/core/coretypes/STObject.dart';

import 'package:chainwallet/src/core/serialized/enums/TransactionType.dart';

import 'package:chainwallet/src/core/types/tx/Transaction.dart';
import 'package:chainwallet/src/core/types/txns/Payment.dart';
import 'package:chainwallet/src/core/types/txns/TrustSet.dart';

/***
 *
 *
 *
 */
class STObjectFormatter {
  //TODO
  static STObject doFormatted(STObject source) {
    // This would need to go before the test that just checks
    // for ledgerEntryType
//    if (AffectedNode.isAffectedNode(source)) {
//      return new AffectedNode(source);
//    }
//
//    if (TransactionMeta.isTransactionMeta(source)) {
//      TransactionMeta meta = new TransactionMeta();
//      meta.fields = source.fields;
//      return meta;
//    }
//
//    LedgerEntryType ledgerEntryType = STObject.ledgerEntryType(source);
//    if (ledgerEntryType != null) {
//      return ledgerFormatted(source, ledgerEntryType);
//    }
//
    TransactionType transactionType = STObject.transactionType(source);
    if (transactionType != null) {
      return transactionFormatted(source, transactionType);
    }

    return source;
  }

  static STObject transactionFormatted(
      STObject source, TransactionType transactionType) {
    STObject constructed = null;

    if (transactionType.runtimeType == TransactionType.Invalid) {
    } else if (transactionType.runtimeType == TransactionType.Payment) {
      constructed = new Payment();
    } else if (transactionType.runtimeType == TransactionType.TrustSet) {
      constructed = new TrustSet();
    }

    if (constructed == null) {
      constructed = new Transaction(transactionType);
    }

    constructed.fields = source.fields;
    return constructed;
  }
}
